@@ -3,27 +3,15 @@
  *
  * Copyright (C) 2005-2010  NTT DATA CORPORATION
  *
- * Version: 1.8.0-pre   2010/10/18
+ * Version: 1.8.0-pre   2010/10/25
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
  *
  */
 
-#include <linux/slab.h>
-#include <linux/highmem.h>
-#include <linux/version.h>
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 0)
-#include <linux/namei.h>
-#include <linux/mount.h>
-#endif
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 30)
-#include <linux/fs_struct.h>
-#endif
 #include "internal.h"
 
-/* Variables definitions.*/
-
 /*
  * The global domains referred by "use_group" keyword.
  *
@@ -94,10 +82,10 @@ int ccs_update_policy(struct ccs_acl_head *new_entry, const int size,
  *
  * Returns true if @a == @b, false otherwise.
  */
-static inline bool ccs_same_acl_head(const struct ccs_acl_info *p1,
-				     const struct ccs_acl_info *p2)
+static inline bool ccs_same_acl_head(const struct ccs_acl_info *a,
+				     const struct ccs_acl_info *b)
 {
-	return p1->type == p2->type && p1->cond == p2->cond;
+	return a->type == b->type && a->cond == b->cond;
 }
 
 /**
@@ -448,7 +436,7 @@ int ccs_delete_domain(char *domainname)
 		return 0;
 	/* Is there an active domain? */
 	list_for_each_entry_srcu(domain, &ccs_domain_list, list, &ccs_ss) {
-		/* Never delete ccs_kernel_domain . */
+		/* Never delete ccs_kernel_domain. */
 		if (domain == &ccs_kernel_domain)
 			continue;
 		if (domain->is_deleted ||
@@ -634,7 +622,7 @@ retry:
 	task->ccs_flags |= CCS_TASK_IS_IN_EXECVE;
 	/*
 	 * Make task->ccs_flags visible to GC before changing
-	 * task->ccs_domain_info .
+	 * task->ccs_domain_info.
 	 */
 	smp_mb();
 	/*
@@ -791,6 +779,7 @@ static void ccs_unescape(unsigned char *dest)
 }
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 36)
+
 /**
  * ccs_copy_argv - Wrapper for copy_strings_kernel().
  *
@@ -806,7 +795,9 @@ static int ccs_copy_argv(const char *arg, struct linux_binprm *bprm)
 		bprm->argc++;
 	return ret;
 }
+
 #else
+
 /**
  * ccs_copy_argv - Wrapper for copy_strings_kernel().
  *
@@ -822,6 +813,34 @@ static int ccs_copy_argv(char *arg, struct linux_binprm *bprm)
 		bprm->argc++;
 	return ret;
 }
+
+#endif
+
+#if LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 35)
+
+/**
+ * get_fs_root - Get reference on root directory.
+ *
+ * @fs:   Pointer to "struct fs_struct".
+ * @root: Pointer to "struct path".
+ *
+ * Returns nothing.
+ *
+ * This is for compatibility with older kernels.
+ */
+static inline void get_fs_root(struct fs_struct *fs, struct path *root)
+{
+	read_lock(&fs->lock);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25)
+	*root = fs->root;
+	path_get(root);
+#else
+	root->dentry = dget(fs->root);
+	root->mnt = mntget(fs->rootmnt);
+#endif
+	read_unlock(&fs->lock);
+}
+
 #endif
 
 /**
@@ -1045,7 +1064,7 @@ static bool ccs_find_execute_handler(struct ccs_execve *ee, const u8 type)
 	struct ccs_request_info *r = &ee->r;
 	/*
 	 * To avoid infinite execute handler loop, don't use execute handler
-	 * if the current process is marked as execute handler .
+	 * if the current process is marked as execute handler.
 	 */
 	if (ccs_current_flags() & CCS_TASK_IS_EXECUTE_HANDLER)
 		return false;
@@ -1061,9 +1080,9 @@ static bool ccs_find_execute_handler(struct ccs_execve *ee, const u8 type)
 #ifdef CONFIG_MMU
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23)
 #define CCS_BPRM_MMU
-#elif defined(RHEL_MAJOR) && RHEL_MAJOR == 5 && defined(RHEL_MINOR) && RHEL_MINOR >= 3
+#elif defined(RHEL_MAJOR) && RHEL_MAJOR == 5
 #define CCS_BPRM_MMU
-#elif defined(AX_MAJOR) && AX_MAJOR == 3 && defined(AX_MINOR) && AX_MINOR >= 2
+#elif defined(AX_MAJOR) && AX_MAJOR == 3
 #define CCS_BPRM_MMU
 #endif
 #endif
@@ -1171,6 +1190,8 @@ int ccs_start_execve(struct linux_binprm *bprm, struct ccs_execve **eep)
  * @retval: Return code of an execve() operation.
  * @ee:     Pointer to "struct ccs_execve".
  *
+ * Returns nothing.
+ *
  * Caller holds ccs_read_lock().
  */
 void ccs_finish_execve(int retval, struct ccs_execve *ee)
@@ -1182,7 +1203,7 @@ void ccs_finish_execve(int retval, struct ccs_execve *ee)
 		task->ccs_domain_info = ee->previous_domain;
 		/*
 		 * Make task->ccs_domain_info visible to GC before changing
-		 * task->ccs_flags .
+		 * task->ccs_flags.
 		 */
 		smp_mb();
 	} else {
@@ -1216,7 +1237,7 @@ void ccs_finish_execve(int retval, struct ccs_execve *ee)
  * if do_execve() failed.
  * Garbage collector does not remove "struct ccs_domain_info" from
  * ccs_domain_list nor kfree("struct ccs_domain_info") if the current thread is
- * marked as CCS_TASK_IS_IN_EXECVE .
+ * marked as CCS_TASK_IS_IN_EXECVE.
  */
 static int __ccs_search_binary_handler(struct linux_binprm *bprm,
 				       struct pt_regs *regs)
